//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Scan/ISpecularScan.cpp
//! @brief     Implements interface ISpecularScan.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sim/Scan/ISpecularScan.h"
#include "Base/Axis/IAxis.h"
#include "Base/Spin/SpinMatrix.h"
#include "Device/Pol/PolFilter.h"
#include "Resample/Element/SpecularElement.h"

ISpecularScan::ISpecularScan(IAxis* axis, double lambda0)
    : m_axis(axis)
    , m_lambda0(lambda0)
{
}

ISpecularScan::~ISpecularScan() = default;

void ISpecularScan::setIntensity(double intensity)
{
    m_intensity = intensity;
}

void ISpecularScan::setPolarization(R3 bloch_vector)
{
    m_beamPolarization.reset(new R3(bloch_vector));
}

void ISpecularScan::setAnalyzer(R3 direction, double efficiency, double total_transmission)
{
    m_polAnalyzer.reset(new PolFilter(direction, efficiency, total_transmission));
}

size_t ISpecularScan::nScan() const
{
    return m_axis->size();
}

bool ISpecularScan::polarized() const
{
    return m_beamPolarization || m_polAnalyzer;
}

SpinMatrix ISpecularScan::polarizerMatrix() const
{
    return m_beamPolarization ? SpinMatrix::FromBlochVector(*m_beamPolarization) : SpinMatrix();
}

SpinMatrix ISpecularScan::analyzerMatrix() const
{
    return m_polAnalyzer ? m_polAnalyzer->matrix() : SpinMatrix();
}
