+++
title = "Understand the syntax"
weight = 30
+++

## Python syntax used in BornAgain scripts

We shall employ the same reflectometry script
as on the [preceding page]({{% ref-py "start/run.md" %}})
to explain some Python syntax used in BornAgain scripts.

For easy reference, here again the full script:

{{< highlightfile file="Examples/specular/AlternatingLayers1.py">}}
<p>

We shall now explain the code.

The [shebang](https://en.wikipedia.org/wiki/Shebang_(Unix)) line
{{< highlight python >}}
#!/usr/bin/env python3
{{< /highlight >}}
makes the script executable under Unix-like operating systems,
see the chapter on [how to run]({{% ref-py "start/run.md" %}}) scripts
from the command line.

Lines between triple quotes
{{< highlight python >}}
"""
Text, text, text
"""
{{< /highlight >}}
are comments.

The block
{{< highlight python >}}
def get_sample():
    from bornagain import std_samples
    return std_samples.alternating_layers()
{{< /highlight >}}
defines the function `get_sample` that
imports the BornAgain submodule [std_samples]({{% ref-src "Wrap/Python/std_samples.py" %}}),
and returns the alternating layers sample model.

Similarly, the next block
{{< highlight python >}}
def get_simulation(sample, scan_size=500):
    from bornagain import std_simulations
    return std_simulations.specular(sample, scan_size)
{{< /highlight >}}
defines the function `get_simulation` that)
imports the BornAgain submodule [std_simulations]({{% ref-src "Wrap/Python/std_simulations.py" %}}),
and returns a standard setup to simulate a specular reflectivity scan.

The clause
{{< highlight python >}}
if __name__ == '__main__':
{{< /highlight >}}
ensures that the following statements are only executed
if the script is called directly, as a "main" program.
This precaution is required by the GUI, where scripts can be imported without
being immediately executed.

In the main block, the statement
{{< highlight python >}}
    ba_plot.run_and_plot(simulation)
{{< /highlight >}}
runs the previously defined simulation, and calls MatPlotLib to display the results.
The function `run_and_plot` is implemented in the module
[ba_plot]({{% ref-src "Wrap/Python/ba_plot.py" %}}).
